package CatalystX::Example::YUIUploader::View::JSON;

use strict;
use base 'Catalyst::View::JSON';

=head1 NAME

CatalystX::Example::YUIUploader::View::JSON - Catalyst JSON View

=head1 SYNOPSIS

See L<CatalystX::Example::YUIUploader>

=head1 DESCRIPTION

Catalyst JSON View.

=head1 AUTHOR

A clever guy

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
