/*
Copyright (c) 2008, Yahoo! Inc. All rights reserved.
Code licensed under the BSD License:
http://developer.yahoo.net/yui/license.txt
version: 2.5.0
*/
/* foundational CSS */
.yui-dt {
    border:1px solid transparent;
}

.yui-dt-noop {
    border:none;
}

.yui-dt-liner {
    overflow:hidden;
}

/* a11y headers */
.yui-dt-bd thead tr, .yui-dt-bd thead th {
    position:absolute;
    left:-1500px;
}

/* draggable columns */
.yui-dt-draggable {
    cursor: move;
}
.yui-dt-coltarget {
    position: absolute;
    z-index: 999;
}

/* resizeable columns */
.yui-dt-hd {
    zoom:1; 
}
th.yui-dt-resizeable .yui-dt-liner {
    position:relative;
}
.yui-dt-resizer {
    position:absolute;
    right:0;
    bottom:0;
    height:100%;
    cursor:e-resize;
    cursor:col-resize;
}
.yui-dt-resizerproxy {
    visibility:hidden;
    position:absolute;
    z-index:9000;
}

/* hidden columns */
.yui-skin-sam th.yui-dt-hidden .yui-dt-liner, 
.yui-skin-sam td.yui-dt-hidden .yui-dt-liner {
    margin:0;
    padding:0;
    overflow:hidden;
    white-space:nowrap;
}

/* vertical and horizontal scrolling */
.yui-dt-scrollable .yui-dt-bd {
    overflow:auto;
}
.yui-dt-scrollable .yui-dt-hd {
    overflow:hidden;
    position:relative; /* for ie overflow bug http://rowanw.com/bugs/overflow_relative.htm */
} 

/* editing */
.yui-dt-editor {
    position:absolute;z-index:9000;
}
